import { DataSource, ViewEntity, ViewColumn } from 'typeorm';
import { Carrito } from '../carrito.entity';
import { Institucion } from '../../../institucion/entity/institucion.entity';
import { Modulo } from '../../../modulo/entity/modulo.entity';
import { Marca } from '../../../marca/entity/marca.entity';
import { Modelo } from '../../../modelo/entity/modelo.entity';
import { TipoCarrito } from '../../../institucion-tipo-carrito/entity/tipo-carrito.entity';

@ViewEntity({
  expression: (dataSource: DataSource) =>
    dataSource
      .createQueryBuilder()
      .select('c.id_carrito', 'id_carrito')
      .addSelect('c.activo', 'activo')
      .addSelect('c.carrito', 'carrito')
      .addSelect('c.id_marca', 'id_marca')
      .addSelect('c.id_modelo', 'id_modelo')
      .addSelect('c.id_modulo', 'id_modulo')
      .addSelect('c.id_tipo_carrito', 'id_tipo_carrito')
      .addSelect('m.id_institucion', 'id_institucion')
      .addSelect('m.modulo', 'modulo')
      .addSelect('ma.marca', 'marca')
      .addSelect('mo.modelo', 'modelo')
      .addSelect('tc.tipo_carrito', 'tipo_carrito')
      .addSelect('i.institucion', 'institucion')
      .from(Carrito, 'c')
      .innerJoin(Marca, 'ma', 'ma.id_marca = c.id_marca')
      .innerJoin(Modelo, 'mo', 'mo.id_modelo = c.id_modelo')
      .innerJoin(Modulo, 'm', 'm.id_modulo = c.id_modulo')
      .innerJoin(TipoCarrito, 'tc', 'tc.id_tipo_carrito = c.id_tipo_carrito')
      .innerJoin(Institucion, 'i', 'i.id_institucion = m.id_institucion')
      .orderBy('institucion', 'ASC')
      .addOrderBy('modulo', 'ASC')
      .addOrderBy('tipo_carrito', 'ASC')
      .addOrderBy('carrito', 'ASC'),
})
export class FullInformacionCarritoView {
  @ViewColumn()
  id_carrito: number;

  @ViewColumn()
  activo: number;

  @ViewColumn()
  carrito: string;

  @ViewColumn()
  id_institucion: number;

  @ViewColumn()
  id_marca: number;

  @ViewColumn()
  id_modelo: number;

  @ViewColumn()
  id_modulo: number;

  @ViewColumn()
  id_tipo_carrito: number;

  @ViewColumn()
  institucion: string;

  @ViewColumn()
  marca: string;

  @ViewColumn()
  modelo: string;

  @ViewColumn()
  modulo: string;

  @ViewColumn()
  tipo_carrito: string;
}
