import * as moment from 'moment';
import { forwardRef, Inject, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { Equipo } from '../equipo/entity/equipo.entity';
import { EquipoMotivo } from './entity/equipo-motivo.entity';
import { Operador } from '../operador/entity/operador.entity';
import { Status } from '../status/entity/status.entity';
import { EquipoService } from '../equipo/equipo.service';
import { OperadorService } from '../operador/operador.service';
import { StatusService } from '../status/status.service';

@Injectable()
export class EquipoMotivoService {
  constructor(
    @InjectRepository(EquipoMotivo)
    private repository: Repository<EquipoMotivo>,
    @Inject(forwardRef(() => EquipoService))
    private equipoService: EquipoService,
    private operadorService: OperadorService,
    private statusService: StatusService,
  ) {}

  async create(
    equipo: Equipo,
    id_operador: number | Operador,
    id_status: number | Status,
    motivo: string,
  ) {
    const ahora = moment();
    const operador =
      typeof id_operador === 'number'
        ? await this.operadorService.findById(id_operador)
        : id_operador;
    const status =
      typeof id_status === 'number'
        ? await this.statusService.findById(id_status)
        : id_status;

    // Creo registro y lo guardo
    return this.repository.save(
      this.repository.create({
        equipo,
        fecha_creacion: ahora.toDate(),
        motivo,
        operador,
        status,
      }),
    );
  }

  findAllByIdEquipo(id_equipo: number, pagina: number) {
    return this.equipoService.findById(id_equipo).then((equipo) =>
      this.repository.findAndCount({
        where: { equipo },
        skip: (pagina - 1) * 25,
        take: 25,
      }),
    );
  }
}
